import setuptools
setuptools.setup(
    name='wawa_logger',  
    version='1.2',
    author="Nathan Getty",
    author_email="gettynathanj@gmail.com",
    description="internal application",
    packages=setuptools.find_packages()
 )
